package com.iconplus.smartproc.controller;

import com.iconplus.smartproc.helper.model.EmptyRequest;
import com.iconplus.smartproc.helper.model.EmptyResponse;
import com.iconplus.smartproc.model.request.ChangePasswordRequest;
import com.iconplus.smartproc.model.request.ForgotPasswordRequest;
import com.iconplus.smartproc.model.request.LoginRequest;
import com.iconplus.smartproc.model.request.RefreshTokenRequest;
import com.iconplus.smartproc.model.response.LoginResponse;
import com.iconplus.smartproc.model.response.RefreshTokenResponse;
import com.iconplus.smartproc.service.authentication.*;
import org.springframework.web.bind.annotation.*;

@CrossOrigin(origins = "http://localhost:8080", allowCredentials = "true")
@RestController
@RequestMapping("/api/authentication")
public class AuthenticationController {

    private final LoginService loginService;
    private final TokenManagementService tokenManagementService;
    private final LogoutService logoutService;
    private final ChangePasswordService changePasswordService;
    private final ForgotPasswordService forgotPasswordService;

    public AuthenticationController(LoginService loginService,
                                    TokenManagementService tokenManagementService,
                                    LogoutService logoutService,
                                    ChangePasswordService changePasswordService,
                                    ForgotPasswordService forgotPasswordService) {
        this.loginService = loginService;
        this.tokenManagementService = tokenManagementService;
        this.logoutService = logoutService;
        this.changePasswordService = changePasswordService;
        this.forgotPasswordService = forgotPasswordService;
    }

    @PostMapping("/login")
    public LoginResponse getLoginResponse(@RequestBody LoginRequest loginRequest) {
        return loginService.execute(loginRequest);
    }

    @PostMapping("/refresh-token")
    public RefreshTokenResponse getRefreshToken(@RequestBody RefreshTokenRequest refreshTokenRequest) {
        return tokenManagementService.execute(refreshTokenRequest);
    }

    @PostMapping("/logout")
    public EmptyResponse logoutUser(EmptyRequest request) {
        return logoutService.execute(request);

    }

    @PostMapping("/change-password")
    public EmptyResponse changePassword(@RequestBody ChangePasswordRequest changePasswordRequest) {
        return changePasswordService.execute(changePasswordRequest);
    }

    @PostMapping("/forgot-password")
    public EmptyResponse forgotPassword(@RequestBody ForgotPasswordRequest forgotPasswordRequest) {
        return forgotPasswordService.execute(forgotPasswordRequest);
    }

}
